<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" omit-xml-declaration="no"/>
	
	<xsl:variable name="viewer">/tools/explore/</xsl:variable>
	<xsl:variable name="imgbase">/nkse/style/img/</xsl:variable>
	
	 <xsl:include href="res:/nkse/style/xsl/format_resolution.xsl"/>	
	
	<xsl:strip-space elements="n"/>
	
<xsl:template match="/">
	<xsl:call-template name="exception"/>
</xsl:template>
	
<xsl:template name="exception">
	<div>
		
		<script language="JavaScript">
		<xsl:comment>
		function showException()
		{	if (document.getElementById( 'exception' ).style.display=="none")
			{	document.getElementById( 'exception' ).style.display= "";
				scrollTo(0,65535);
			}
			else
			{	document.getElementById( 'exception' ).style.display= "none";
			}
		}
		</xsl:comment>
		</script>
		<style type="text/css">
			
			.headline-id { font-size: x-large; color: #CC0000; font-weight: bold }
			.headline-message { }
			.request { color: black; text-align: center; font-size: 75% }
			.indent { color: white; }
			.endpoint { background: black; text-align: center; color: white; margin: auto; }
			.endpoint-class { font-size: 125%; }
			.endpoint a { color: red; }
			.endpoint a:link	    {text-decoration: none; color: white; }
			.endpoint a:visited   {text-decoration: none; color: white; }
			.endpoint a:hover	    {text-decoration: none; background-color: #938661; color: white; }
			.exception-block { margin-top: 2px; text-align: left; border: solid black 1px; background: #8080FF; color:white; }
			.exception-id { font-size: 120%; font-weight: bold; color: white; }
			.java { padding-left: 1em; background: white; font-size: 75%; color: black; }
			.resolutionblock { background: white; color: black; }
			.error-javastack-level {  }
		</style>
	
		<table border="0" cellspacing="0" cellpadding="2">
		<tr>
		<td valign="top"><img src="{$imgbase}exception.png"/></td>
		<td>
			<xsl:variable name="deepest" select="(descendant-or-self::ex)[last()]"/>
			<xsl:variable name="id" select="$deepest/id"/>
			<xsl:variable name="message" select="$deepest/message"/>
		
			<p>
			<xsl:choose>
				<xsl:when test="$id='com.ten60.netkernel.util.NetKernelException'">
					<div class="headline-id"><xsl:value-of select="$message"/></div>
				</xsl:when>
				<xsl:otherwise>
					<div class="headline-id"><xsl:value-of select="$id"/></div>
					<xsl:call-template name="wrapped">
						<xsl:with-param name="text" select="$message"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			</p>

			<p><br/><a href="" onClick="location.reload(true)">Retry</a> the request.</p>
	
			<p>A detailed <a href="javascript:showException()">Exception Trace </a> is available, please report this
			to the system administrator or use it to identify the source of
			the problem. 
			<div id="exception" style="width:75%; display: none;">
	
			<table>
				<xsl:apply-templates select="ex/ex"/>
			</table>
		</div></p>
		</td></tr></table>

	</div>
	</xsl:template>	
	
	
	

	<xsl:template match="ex">
		<tr><td>
		<xsl:choose>
		
			<xsl:when test="id='RequestFrameException' or id='RequestFrameError'">
				<div class="request">
					<div><img src="{$imgbase}request-arrow-tail.png"/></div>
					<xsl:call-template name="wrapped">
						<xsl:with-param name="text"><xsl:value-of select="request"/></xsl:with-param>
					</xsl:call-template>
					<xsl:if test="asClass">
						<a href="{$viewer}{asClass}">link</a>
					</xsl:if>
					<div><img src="{$imgbase}request-arrow-head.png"/></div>
				</div>	
			</xsl:when>
			
			<xsl:when test="id='SubrequestException' or id='SubrequestError'">
					<table style="width: 100%" class="endpoint"><tr><td>
					<div class="endpoint-class">
					    <xsl:choose>
							<xsl:when test="endpointHash">
								<a href="{$viewer}{endpointHash}">
									<xsl:value-of select="endpoint"/>
								</a>
							</xsl:when>
							<xsl:otherwise><xsl:value-of select="endpoint"/></xsl:otherwise>
						</xsl:choose>
						<xsl:choose>
							<xsl:when test="logicalEndpointHash">
								<a href="{$viewer}{logicalEndpointHash}">[<xsl:value-of select="logicalEndpoint"/>]</a>
							</xsl:when>
							<xsl:otherwise>[<xsl:value-of select="logicalEndpoint"/>]</xsl:otherwise>
						</xsl:choose>
					</div>
					<div>
						<xsl:choose>
							<xsl:when test="spaceHash">
							    <a href="{$viewer}{spaceHash}">
						           <xsl:value-of select="space"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
						       <xsl:value-of select="space"/>
							</xsl:otherwise>
						</xsl:choose>
					</div>
					<xsl:apply-templates select="ex"/>
					</td></tr></table>
			</xsl:when>
			
			<xsl:when test="id!='org.ten60.netkernel.layer0.nkf.NKFException'">
				<div class="exception-block">
					<div class="exception-id"><xsl:value-of select="id"/></div>
					<xsl:if test="string-length(message)">
						<div><xsl:value-of select="message"/></div>
					</xsl:if>
					<xsl:if test="location" >
						<div><xsl:value-of select="location"/></div>
					</xsl:if>
					
					<xsl:if test="stack" >
						<div class="java">
							<xsl:apply-templates select="stack/level"/>
						</div>
					</xsl:if>
					<xsl:if test="trace">
						<xsl:for-each select="trace">
							<div class="resolutionblock">
								<xsl:call-template name="resolution"/>
							</div>
						</xsl:for-each>
					</xsl:if>
				</div>
			</xsl:when>
		</xsl:choose>
		</td></tr>		
	</xsl:template>	
		 
		 
	<xsl:template match="level">
		<div class="error-javastack-level"><xsl:value-of select="."/></div>
	</xsl:template>

	<xsl:template match="s">
		<div><xsl:value-of select="."/></div>
	</xsl:template>
	
	<xsl:template name="wrapped">
		<xsl:param name="text"/>
		<xsl:choose>
			<xsl:when test="string-length($text)>60">
				<xsl:value-of select="substring($text,1,60)"/><wbr/><xsl:call-template name="wrapped">
					<xsl:with-param name="text" select="substring($text,60+1)"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	

</xsl:stylesheet>
